@variables:transition
% Households 
"Consumption" C
"Growth of Consumption q-o-q" dot_C
"Growth of Consumption y-o-y" dot4_C
"Optimal Consumption" Co
"Rule of Thumb Consumption" Cn
"Habit" H
"Labor" L
"Wage" W
"Flexible Wage" Wflex
"Growth of Wage q-o-q" dot_W
"Growth of Wage y-o-y" dot4_W
"Investment" J
"Growth of Investment q-o-q" dot_J
"Growth of Investment y-o-y" dot4_J
"Capital" K
"Price of Capital" Pk
"Inflation of Capital Price" dot_Pk
"Shadow Price of Capital" Q

% Consumption Goods Producers
"Intermediate to Consumption" Yc
"Price of Consumption" Pc
"Inflation of Consumption q-o-q" dot_Pc
"Inflation of Consumption y-o-y" dot4_Pc
"Flexible Price of Consumption" Pcflex

% Intermediate Good Producers
"Intermediate Production " Y
"Growth of Intermediate Production q-o-q" dot_Y
"Growth of Intermediate Production y-o-y" dot4_Y
"Price of Intermediate Good" Py
"Flexible Price of Intermediate Good" Pyflex
"Inflation of Intermediate Good q-o-q" dot_Py
"Inflation of Intermediate Good y-o-y" dot4_Py
"Labor Augmenting Technology" A
"Growth of Labor Augmenting Technology" dot_A

% Investment Good Producers
"Intermediate to Investment" Yj
"Price of Investment Good" Pj
"Flexible Price of Investment" Pjflex
"Inflation of Investment Good" dot_Pj
"Investment Specific Technology" Aj
"Growth of Investment Specific Technology" dot_Aj

% Government Good Producers
"Intermediate to Government" Yg
"Price of Government Good" Pgflex

% Government
"Government Spending on Goods and Services" G
"Growth of Government Spending q-o-q" dot_G
"Growth of Government Spending y-o-y" dot4_G
"Government Transfers" Tf
"Social and Health Security Tax" tau_s
"Wage Tax" tau_w
"Consumption Tax" tau_c
"Persistent Shock to Government Spending" res_G
"Persistent Shock to Government Transfers" res_Tf

% Monetary Policy
"Nominal Interest Rate" I

% Financial Market, Net Governmental Debt and Risk Premium
"Budget Revenues" Rev
"Budget Expenditures" Exp
"Budget Balance" Bal
"Net Governmental Debt" NGD
"Risk Premium" PREM
"Share of Government Debt on Output"  NGD2PyY

@parameters
% Households
"Habit Persistence" chi, "Discount Factor" beta
"Capital Depreciation" delta
"Calvo for Wages" xiw, "Mark-up for Wages" lambda_w
% Intermediate Good Producers
"Share of Labor" alpha
% Calvo Parameters
"Calvo for Consumption" xic, "Calvo for Intermediate" xiy, "Calvo for Investment" xij
% Mark-ups
"Mark-up in Consumption" lambda_c, "Mark-up in Intermediate" lambda_y, "Mark-up in Investment" lambda_j
% Monetary Policy
"Monetary Policy Persistency" gamma
"Monetary Policy Reactiveness" ni
% Government
"Steady-state Debt-to-Output Ratio" NGD2PyY_ss
"Steady-state Social and Health Security Tax" tau_s_ss
"Steady-state Wage Tax" tau_w_ss
"Steady-state Consumption Tax" tau_c_ss
"Share of Government Spending on Output" PgflexG2PyY
"Government Reactiveness" psi
"Persistency of Spending Shocks" rho
"Risk Premium Elasticity" mu
"Transfers to Wages Ratio" omega
% Technologies
"Persistency of shocks" theta

@equations:transition
%% Households <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
(Co{+1} - chi*H{+1})/(Co - chi*H) = (beta/PREM)*@exp(I)*((Pc*(1+tau_c))/(Pc{+1}*(1+tau_c{+1})));
Cn*Pc*(1+tau_c) = Tf;

C =  Co + Cn;

H = C{-1}*@exp(shk_H);

W/(Pc*(1+tau_c)) = (Co - chi*H);

% Sticky wages
dot_W = beta/(1+beta)*dot_W{1} + 1/(1+beta)*dot_W{-1} + ((1-beta*xiw)*(1-xiw)/(xiw*(1+beta)))*@log(Wflex*(1-tau_w)/W*lambda_w) + shk_W;

% Capital accumulation
K = K{-1}^(1-delta)*(@exp(shk_Ca)*J/delta)^delta;
Q = (Pj*J)/(delta*K);
Q = (Pk{+1} + Q{+1}*(1-delta)*(K{+1}/K))/@exp(I);

%% Intermediate Good Producers <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
Y = (A*L)^(alpha)*K{-1}^(1-alpha)*@exp(shk_Y);
W*(1+tau_s) = alpha*Pyflex*Y/L;
Pk = (1-alpha)*Pyflex*Y/K{-1};

dot_Py = beta/(1+beta)*dot_Py{1} + 1/(1+beta)*dot_Py{-1} + ((1-beta*xiy)*(1-xiy)/(xiy*(1+beta)))*@log(Pyflex/Py*lambda_y);

%% Consumption Good Producers <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
Yc = C;
Pcflex = Py;

dot_Pc = beta/(1+beta)*dot_Pc{1} + 1/(1+beta)*dot_Pc{-1} + ((1-beta*xic)*(1-xic)/(xic*(1+beta)))*@log(Pcflex/Pc*lambda_c) + shk_Pc;

%% Investment Good Producers <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
J = Aj*Yj;
Pjflex = Py/Aj;

dot_Pj = beta/(1+beta)*dot_Pj{1} + 1/(1+beta)*dot_Pj{-1} + ((1-beta*xiy)*(1-xiy)/(xij*(1+beta)))*@log(Pjflex/Pj*lambda_j);

%% Government Good Producers <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
Pgflex = Py;
G = Yg;
 
%% Monetary Policy <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
I = gamma*I{-1} + (1-gamma)*(@log((1/beta)*PREM) + dot_Pc{1} + ni*dot_Pc{1})+ shk_I;

%% Government <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< 
%Government Spending
Bal/(Py*Y)*res_G = -(1-@exp(I))*NGD2PyY{-1} + psi*(NGD/(Py*Y) - NGD2PyY);

NGD2PyY = NGD2PyY{-1}^0.5*NGD2PyY_ss^0.5*@exp(shk_NGD2PyY);

res_G = res_G{-1}^rho*@exp(shk_G);

%Transfers
Tf = W^omega*res_Tf;
res_Tf = res_Tf{-1}^rho*@exp(shk_Tf);

%Social and Health Security Tax
tau_s = tau_s_ss + shk_tau_s;

%Wage Tax
tau_w = tau_w_ss + shk_tau_w;

%Consumption Tax
tau_c = tau_c_ss + shk_tau_c;

%% Government Spending, Net Governmental Debt and Risk Premium <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
Rev = W*L*tau_w + W*L*tau_s + Pc*C*tau_c;
Exp = Pgflex*G + Tf;
Bal = Rev - Exp;

NGD = NGD{-1}*@exp(I{-1}) - Bal;

PREM = @exp(NGD/(Py*Y))^(mu)*@exp(shk_PREM);

%% Identities <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
Y = Yc + Yj + Yg;

%% Technologies <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
A = A{-1}^theta*@exp(shk_A);
Aj = Aj{-1}^theta*@exp(shk_Aj);

%% Growths <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
dot_A  = @log(A/A{-1});
dot_Aj  = @log(Aj/Aj{-1});
dot_C  = @log(C/C{-1});
dot_J  = @log(J/J{-1});
dot_G  = @log(G/G{-1});
dot_Y  = @log(Y/Y{-1});
dot_W = @log(W/W{-1});
dot_Pc = @log(Pc/Pc{-1});
dot_Py = @log(Py/Py{-1});
dot_Pk = @log(Pk/Pk{-1});
dot_Pj = @log(Pj/Pj{-1});

dot4_C  = @log(C/C{-4});
dot4_J  = @log(J/J{-4});
dot4_G  = @log(G/G{-4});
dot4_Y  = @log(Y/Y{-4});
dot4_W = @log(W/W{-4});
dot4_Pc = @log(Pc/Pc{-4});
dot4_Py = @log(Py/Py{-4});

@variables:residual
"Habit Shock" shk_H
"Wage Mark-up Shock" shk_W
"Capital Accumulation Shock" shk_Ca

"Consumption Price Mark-up Shock" shk_Pc

"Productivity Shock" shk_Y
"Permanent Productivity Shock" shk_A
"Investment Specific Productivity Shock" shk_Aj

"Monetary Policy Shock" shk_I

"Government Spending Shock" shk_G
"Government Transfers Shock" shk_Tf
"Social and Health Security Tax Shock" shk_tau_s
"Wage Tax Shock" shk_tau_w
"Consumption Tax Shock" shk_tau_c
"Shock to Share of Government Debt on Output" shk_NGD2PyY
"Shock to Risk premium" shk_PREM

@variables:log
@allbut dot_A, dot_Aj, dot_C, dot_J, dot_G, dot_Y, dot_W, dot_Pc, dot_Py, dot_Pj, dot_Pk, I, tau_s, tau_w, tau_c, dot4_C, dot4_J, dot4_G, dot4_Y, dot4_W, dot4_Pc, dot4_Py