close all
clear all

%% Read the Model
disp('Reading and Solving the Model ...');

readmodel_tf;


disp('Simulating ...');

sdate = qq(2009,1);
d = sstatedb(m, sdate-4:sdate+100);

d.NGD2PyY(sdate+1:sdate+1) =  d.NGD2PyY + 0.02;
d.NGD2PyY(sdate+2:sdate+2) =  d.NGD2PyY + 0.04;
d.NGD2PyY(sdate+3:sdate+3) =  d.NGD2PyY + 0.06;
d.NGD2PyY(sdate+4:sdate+4) =  d.NGD2PyY + 0.08;
d.NGD2PyY(sdate+5:sdate+5) =  d.NGD2PyY + 0.10;
d.NGD2PyY(sdate+6:sdate+6) =  d.NGD2PyY + 0.12;
d.NGD2PyY(sdate+7:sdate+7) =  d.NGD2PyY + 0.14;
d.NGD2PyY(sdate+8:sdate+100) =  d.NGD2PyY + 0.16;

simplan = plan(m,sdate+1:sdate+100);
simplan = exogenize(simplan,'NGD2PyY',sdate+1:sdate+100);
simplan = endogenize(simplan,'shk_NGD2PyY',sdate+1:sdate+100);

% Simulates the disinflation
s = simulate(m,d,sdate:sdate+100,'plan',simplan);
s = dboverlay(d,s);

%% Make Report
Plotrng = sdate-1:sdate+28;

x = report('heading', 'Report on Permanent Increase in Debt-to-Output Ratio', 'color', true, 'visible', false);

x = opengraph(x);

x = tag(x,'Debt-Financed Increase in Transfers','fontsize','large');

  subplot(3,3,1); hold on;
  plot(Plotrng,[s.Rev/(s.Py*s.Y)],'linewidth',2); title('Budget Revenues/Output'); 
  grid on; box off;  
  
  subplot(3,3,2); hold on;
  plot(Plotrng,[(s.Exp)/(s.Py*s.Y)],'linewidth',2); title('Budget Expenditures/Output');
  grid on; box off; 
    
  subplot(3,3,3); hold on;
  plot(Plotrng,[(s.Pgflex*s.G)/(s.Py*s.Y)],'linewidth',2); title('Government Spending (G)/Output');
  grid on; box off;
    
  subplot(3,3,4); hold on;
  plot(Plotrng,[s.Tf/(s.Py*s.Y)],'linewidth',2); title('Transfers/Ouptut');
  grid on; box off;
  
  subplot(3,3,5); hold on;
  plot(Plotrng,[(s.Bal)/(s.Py*s.Y)],'linewidth',2); title('Primary Balance/Output'); 
  grid on; box off;
  
  subplot(3,3,6);
  plot(Plotrng,[(s.tau_c)],'linewidth',2);
  hold on
  plot(Plotrng,[(s.tau_w)],'linewidth',2,'linestyle','--');
  title('Taxes');
  legend ('Consumption Tax', 'Wage Tax');
  grid on; box off;
  
  subplot(3,3,7); hold on;
  plot(Plotrng,[100*s.dot4_Y],'linewidth',2); title('Output Growth (y-o-y)'); 
  grid on; box off;
  
  subplot(3,3,8); hold on;
  plot(Plotrng,[s.NGD/(s.Py*s.Y)],'linewidth',2); title('Net Government Debt/Output'); 
  grid on; box off;
  
  subplot(3,3,9); hold on;
  plot(Plotrng,[400*log(s.PREM)],'linewidth',2); title('Risk Premium'); 
  grid on; box off;

x = getgraph(x);

x = newpage(x);

x = opengraph(x);

x = tag(x,'Debt-Financed Increase in Transfers','fontsize','large');

  subplot(3,3,1); hold on;
  plot(Plotrng,[100*s.dot4_C],'linewidth',2); title('Total Consumption (growth, y-o-y)');
  grid on; box off;
  
  subplot(3,3,2); hold on;
  plot(Plotrng,[100*log(s.Cn/s.Cn{-4})],'linewidth',2); title('Cons. of Hand-to-Mouth H. (growth, y-o-y)'); 
  grid on; box off;  

  subplot(3,3,3); hold on;
  plot(Plotrng,[s.C/s.Y],'linewidth',2); title('Consumption/Output'); 
  grid on; box off;
  
  subplot(3,3,4); hold on;
  plot(Plotrng,[100*s.dot4_J],'linewidth',2); title('Investment (growth, y-o-y)'); 
  grid on; box off;

  subplot(3,3,5); hold on;
  plot(Plotrng,[s.K/(s.Y)],'linewidth',2); title('Capital/Output'); 
  grid on; box off;
    
  subplot(3,3,6); hold on;
  plot(Plotrng,[100*log(s.L/s.L{-4})],'linewidth',2); title('Hours Worked (y-o-y)'); 
  grid on; box off;
    
  subplot(3,3,7); hold on;
  plot(Plotrng,[100*s.dot4_W],'linewidth',2); title('Nominal Wage (growth, y-o-y)'); 
  grid on; box off;
  
  subplot(3,3,8); hold on;
  plot(Plotrng,[100*s.dot4_Pc,],'linewidth',2); title('Inflation (y-o-y)'); 
  grid on; box off;    
  
  subplot(3,3,9); hold on;
  plot(Plotrng,[400*s.I],'linewidth',2); title('Nominal Interest Rate');
  grid on; box off;
  
x = getgraph(x);

compile(x,'Report_NGD2GDP_increase_Tf.pdf');
compile(x,'Report_NGD2GDP_increase_Tf.ps','display',false);

disp('Done ...');